==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/CustomcontroldefaultconfigCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.CollectionPageNonEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.annotation.Function;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Customcontroldefaultconfig;
import microsoft.dynamics.crm.entity.request.CustomcontroldefaultconfigRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class CustomcontroldefaultconfigCollectionRequest extends CollectionPageEntityRequest<Customcontroldefaultconfig, CustomcontroldefaultconfigRequest>{

    protected ContextPath contextPath;

    public CustomcontroldefaultconfigCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Customcontroldefaultconfig.class, cp -> new CustomcontroldefaultconfigRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    @Function(name = "RetrieveUnpublishedMultiple")
    @JsonIgnore
    public CollectionPageNonEntityRequest<Customcontroldefaultconfig> retrieveUnpublishedMultiple() {
        Map<String, TypedObject> _parameters = ParameterMap.empty();
        return CollectionPageNonEntityRequest.forFunction(this.contextPath.addActionOrFunctionSegment("Microsoft.Dynamics.CRM.RetrieveUnpublishedMultiple"), Customcontroldefaultconfig.class, _parameters, microsoft.dynamics.crm.schema.SchemaInfo.INSTANCE);
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/CustomcontroldefaultconfigCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.CollectionPageNonEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.annotation.Function;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Customcontroldefaultconfig;
import microsoft.dynamics.crm.entity.request.CustomcontroldefaultconfigRequest;

public class CustomcontroldefaultconfigCollectionRequest extends CollectionPageEntityRequest<Customcontroldefaultconfig, CustomcontroldefaultconfigRequest>{

    protected ContextPath contextPath;

    public CustomcontroldefaultconfigCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Customcontroldefaultconfig.class, cp -> new CustomcontroldefaultconfigRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    @Function(name = "RetrieveUnpublishedMultiple")
    @JsonIgnore
    public CollectionPageNonEntityRequest<Customcontroldefaultconfig> retrieveUnpublishedMultiple() {
        Map<String, TypedObject> _parameters = ParameterMap.empty();
        return CollectionPageNonEntityRequest.forFunction(this.contextPath.addActionOrFunctionSegment("Microsoft.Dynamics.CRM.RetrieveUnpublishedMultiple"), Customcontroldefaultconfig.class, _parameters);
    }

}
